# textmidiformedit package

This is the package for textmidiformedit.py.
textmidiformedit.py is a python program with supporting modules
for editing forms that are used by textmidicgm, the
textmidi Computer-generated music program.
